@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11402 2019-03-26 18:21:13Z Lavender $
+# $Id: __init__.py 11430 2019-04-10 05:13:37Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-03-27 03:21:13 +0900 (週三, 27 三月 2019) $
-# $Revision: 11402 $
+# $Date: 2019-04-10 14:13:37 +0900 (週三, 10 四月 2019) $
+# $Revision: 11430 $
 
 from __future__ import print_function
 
@@ -666,17 +666,12 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
 
     #=========================================================================
     # Django plugins.
+    if DJANGO_VERSION >= 210: # django >= 1.11
+        MIDDLEWARE = 'MIDDLEWARE'
+    else:
+        MIDDLEWARE = 'MIDDLEWARE_CLASSES'
+        
     pluginsDefaults = {
-        'MIDDLEWARE_CLASSES': (
-            'django.contrib.sessions.middleware.SessionMiddleware',
-            'django.middleware.common.CommonMiddleware',
-            'django.middleware.csrf.CsrfViewMiddleware',
-            'django.contrib.auth.middleware.AuthenticationMiddleware',
-            'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
-            'django.contrib.messages.middleware.MessageMiddleware',
-            'django.middleware.clickjacking.XFrameOptionsMiddleware',
-            'django.middleware.security.SecurityMiddleware',
-        ),
         'INSTALLED_APPS': (
             'django.contrib.admin',
             'django.contrib.auth',
@@ -688,8 +683,18 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
             'Iuppiter.i18n',
             'Iuno.member',
         ),
+        MIDDLEWARE: (
+            'django.contrib.sessions.middleware.SessionMiddleware',
+            'django.middleware.common.CommonMiddleware',
+            'django.middleware.csrf.CsrfViewMiddleware',
+            'django.contrib.auth.middleware.AuthenticationMiddleware',
+            'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
+            'django.contrib.messages.middleware.MessageMiddleware',
+            'django.middleware.clickjacking.XFrameOptionsMiddleware',
+            'django.middleware.security.SecurityMiddleware',
+        )
     }
-
+    
     if warns:
         warnWithout('INSTALLED_APPS', settingsDict, pluginsDefaults)
 
