@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 11263 2018-11-22 14:47:09Z Lavender $
+# $Id: Util.py 11435 2019-04-10 13:43:34Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,11 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-11-22 22:47:09 +0800 (Thu, 22 Nov 2018) $
-# $Revision: 11263 $
+# $Date: 2019-04-10 22:43:34 +0900 (週三, 10 四月 2019) $
+# $Revision: 11435 $
 
 import sys
+import six
 import hashlib
 import urllib
 
@@ -32,6 +33,9 @@ from Iuppiter.Encoding import utf8
 
 # ​https://github.com/vinta/python-pay2go
 
+def toBytes(s):
+    return s if six.PY2 else s.encode()
+
 class Pay2GoMPGAPI(object):
 
     def __init__(self, hashKey, hashIv, sandbox, *args, **kwargs):
@@ -90,9 +94,9 @@ class CathaybkAPI(object):
         self.cubkey = cubkey
 
     def generateCheckValue(self, data):
-        checkValue = hashlib.md5(
+        checkValue = hashlib.md5(toBytes(
             self.merchantId + data['ORDERNUMBER'] + 
-            str(data['AMOUNT']) + self.cubkey).hexdigest()
+            str(data['AMOUNT']) + self.cubkey)).hexdigest()
         return checkValue
 
     def buildXml(self, data):
