@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11432 2019-04-10 06:04:43Z Lavender $
+# $Id: __init__.py 11442 2019-04-12 12:01:47Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,21 +12,23 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-04-10 15:04:43 +0900 (週三, 10 四月 2019) $
-# $Revision: 11432 $
+# $Date: 2019-04-12 21:01:47 +0900 (週五, 12 四月 2019) $
+# $Revision: 11442 $
 
 import os
 import sys
 import warnings
 import json
+import six
 import datetime
 import urllib
 import hashlib
 
+
 from collections import OrderedDict
 
 from Iuppiter.Encoding import utf8
-from Iuno import warnWithout, update, require
+from Iuno import warnWithout, update, require, DJANGO_VERSION
 from Iuppiter.DjangoUtil import (extendInstalledApps, 
                                  extendMiddlewareClasses, 
                                  extendTemplateContextProcessors,
@@ -43,6 +45,10 @@ from django.core.urlresolvers import reverse
 
 from Iuno.Patch import patterns
 
+from Iuppiter.Logging import createLogger
+
+logger = createLogger(__name__)
+
 CKEDITOR_CONFIGS = {
     'default': {
         'skin': 'moono',
@@ -261,9 +267,11 @@ def attachSettings(settingsDict, enablePaypal=False):
     # 先以目前的寫法帶過
     # see #2784
     addOscarDefaultsPackages = {}
+    _level = -1 if six.PY2 else 0
     oscarDefaultsPackages = __import__(
-            'oscar.defaults', globals(), locals(), [], -1
+            'oscar.defaults', globals(), locals(), [], _level
         ).__dict__['defaults']
+        
     for attr in dir(oscarDefaultsPackages):
         addOscarDefaultsPackages[attr] = getattr(
             oscarDefaultsPackages, attr)
@@ -461,8 +469,8 @@ def attachShopURLs(settings, urlpatterns):
     urlpatterns += patterns('',
         # the i18n is the default url settings of django oscar, but generally
         # we are not used.
-        (r'^i18n/', include('django.conf.urls.i18n')),
-        (r'^shop/', shop.urls),
+        url(r'^i18n/', include('django.conf.urls.i18n')),
+        url(r'^shop/', shop.urls),
     )
     
     ckeditorEnable = False
@@ -564,7 +572,7 @@ from django.utils.translation import ugettext_lazy as _
 from pyallpay import AllPay
 
 from Iuppiter.Encoding import utf8
-from Iuno.shop.Util import Pay2GoMPGAPI, CathaybkAPI
+from Iuno.shop.Util import Pay2GoMPGAPI, CathaybkAPI, toBytes
 
 ECPAY_SANDBOX_SERVICE_URL = \
                     'https://payment-stage.ecpay.com.tw/Cashier/AioCheckOut/V2'
@@ -608,18 +616,47 @@ class AllPay2(AllPay):
 def buildAPIForm(submission, request, apiName, extra={}):
     scheme = request.scheme
     domain = request.META['HTTP_HOST']
+    
+    from django.conf import settings
+    
+    ecpayEnable = False
+    if hasattr(settings, 'IUNO_SHOP_ECPAY_ENABLE'):
+        ecpayEnable = settings.IUNO_SHOP_ECPAY_ENABLE
+
+    allpayEnable = False
+    if hasattr(settings, 'IUNO_SHOP_ALLPAY_ENABLE'):
+        allpayEnable = settings.IUNO_SHOP_ALLPAY_ENABLE
+
+    spgatewayEnable = False
+    if hasattr(settings, 'IUNO_SHOP_SPGATEWAY_ENABLE'):
+        spgatewayEnable = settings.IUNO_SHOP_SPGATEWAY_ENABLE
+
+    cathaybkEnable = False
+    if hasattr(settings, 'IUNO_SHOP_CATHAYBK_ENABLE'):
+        cathaybkEnable = settings.IUNO_SHOP_CATHAYBK_ENABLE
+        
+    enable = {
+        SPGATEWAY: spgatewayEnable,
+        ALLPAY: allpayEnable,
+        ECPAY: ecpayEnable,
+        CATHAYBK: cathaybkEnable,
+        ECPAY_LOGISTIC: ecpayEnable,
+        ECPAY_MAP: ecpayEnable,
+    }
 
     if not apiName in [SPGATEWAY, ALLPAY, ECPAY, 
                        CATHAYBK, ECPAY_LOGISTIC, ECPAY_MAP]:
         raise ValueError("Not pay api name: %s" % apiName)
+        
+    if not enable[apiName]:
+        logger.error("The project not enable the payment: %s" % apiName)
+        return ''
 
     MERCHANT_TRADE_NO_LEN = 20
 
     total = submission['order_total'].excl_tax
     basket = submission['basket']
     
-    from django.conf import settings
-    
     # item name
     itemName = utf8('')
     for index, line in enumerate(basket.all_lines()):
@@ -638,7 +675,8 @@ def buildAPIForm(submission, request, apiName, extra={}):
     # merchantTradeNo
     basketId = basket.id
     tradeNo = 'BASKETID%d' % basketId
-    hashCode = hashlib.sha224(str(datetime.datetime.now())).hexdigest().upper()
+    hashCode = hashlib.sha224(
+        toBytes(str(datetime.datetime.now()))).hexdigest().upper()
     lenNo = (MERCHANT_TRADE_NO_LEN - len(tradeNo))
     merchantTradeNo = str(hashCode[0:lenNo]) + tradeNo
     
@@ -663,11 +701,14 @@ def buildAPIForm(submission, request, apiName, extra={}):
             'MerchantID': settings.SPGATEWAY_API_MERCHANT_ID,
             'MerchantOrderNo': merchantTradeNo,
             'Amt': int(total),
-            'ItemDesc': itemName.replace('#', '|'),
+            'ItemDesc': itemName.replace(toBytes('#'), toBytes('|')),
             'LoginType': 0,
             'CREDIT': 1,
             #'UNIONPAY': 1,
         }
+        
+        if six.PY3:
+            data['ItemDesc'] = data['ItemDesc'].decode("utf-8")
 
         mpg = Pay2GoMPGAPI(
             hashKey=settings.SPGATEWAY_API_HASH_KEY,
@@ -692,6 +733,9 @@ def buildAPIForm(submission, request, apiName, extra={}):
             'TradeDesc' : settings.OSCAR_SHOP_NAME, 
             'Remark' : settings.OSCAR_SHOP_NAME,
         }
+        
+        if six.PY3:
+            data['ItemName'] = data['ItemName'].decode("utf-8")
 
         ap = AllPay2(data)
 
@@ -725,13 +769,14 @@ def buildAPIForm(submission, request, apiName, extra={}):
         if apiName == ECPAY:
             form = ap.gen_check_out_form(dictUrl, 
                                     settings.ECPAY_AUTO_SEND_FORM)
-            form = form.replace('allPay-Form', 'ecpayForm')
-            form = form.replace('allPayForm', 'ecpayForm')
+                                    
+            form = form.replace(toBytes('allPay-Form'), toBytes('ecpayForm'))
+            form = form.replace(toBytes('allPayForm'), toBytes('ecpayForm'))
         else:
             form = ap.gen_check_out_form(dictUrl, 
                                     settings.ALLPAY_AUTO_SEND_FORM)
-            form = form.replace('allPay-Form', 'allpayForm')
-            form = form.replace('allPayForm', 'allpayForm')
+            form = form.replace(toBytes('allPay-Form'), toBytes('allpayForm'))
+            form = form.replace(toBytes('allPayForm'), toBytes('allpayForm'))
         
         return form
 
@@ -777,15 +822,28 @@ def buildAPIForm(submission, request, apiName, extra={}):
         else:
             needExtraData = True
 
-        context = Context({
-            'apiUrl': apiUrl,
-            'chantID': settings.ECPAY_API_MERCHANT_ID,
-            'subTypes': subTypes,
-            'returnUrl': returnUrl,
-            'needExtraData': needExtraData,
-            'extraData': json.dumps(
-                data, ensure_ascii=False, default=str).replace("\"", "&quot;"),
-        })
+        if DJANGO_VERSION >= 210: # django >= 1.11
+            context = {
+                'apiUrl': apiUrl,
+                'chantID': settings.ECPAY_API_MERCHANT_ID,
+                'subTypes': subTypes,
+                'returnUrl': returnUrl,
+                'needExtraData': needExtraData,
+                'extraData': json.dumps(
+                    data, ensure_ascii=False, 
+                    default=str).replace("\"", "&quot;"),
+            }
+        else:
+            context = Context({
+                'apiUrl': apiUrl,
+                'chantID': settings.ECPAY_API_MERCHANT_ID,
+                'subTypes': subTypes,
+                'returnUrl': returnUrl,
+                'needExtraData': needExtraData,
+                'extraData': json.dumps(
+                    data, ensure_ascii=False, 
+                    default=str).replace("\"", "&quot;"),
+            })
         form = temp.render(context)
                                       
         return form
